Welcome to ibm-watsonx-data-integration

`ibm-watsonx-data-integration` is a Python SDK that enables developers and data engineers to programmatically interact with the watsonx.data integration service, IBM's next-generation data integration platform built to support modern, hybrid-cloud data pipelines.
With this SDK, users can automate and manage Flow lifecycles such as creating, configuring, starting, stopping, and monitoring Flows directly in code.

Package documentation
=====================

Full documentation is available at:
`https://ibm.github.io/ibm-watsonx-data-integration-sdk <https://ibm.github.io/ibm-watsonx-data-integration-sdk>`_
